<script setup>
import AppLayoutBasic from "@/Layouts/AppLayoutBasic.vue";
import { Link } from '@inertiajs/inertia-vue3';
import DK_Button from '@/components/dk_Button.vue';
import DK_Input from '@/components/dk_Input.vue';
import JetModal from '@/Jetstream/Modal.vue';
import { axiosApiCalls } from '../../../public/libs/datakorumJS';
import { setBlockTracking } from "vue";

</script>
<style>
    .dataTables_filter{
        visibility: hidden;
        height: 0;
    }

    table.dataTable thead th,
    table.dataTable thead td {
        padding: 5px 10px;
        font-size: 0.9rem !important;
        border-bottom: 1px solid rgba(200, 200, 200, 0.75) !important;
    }

    .dataTables_wrapper{
        margin-bottom: 4px !important;
    }

    .dataTables_wrapper .dataTables_paginate .paginate_button.disabled,
    .dataTables_wrapper .dataTables_paginate .paginate_button.disabled:hover,
    .dataTables_wrapper .dataTables_paginate .paginate_button.disabled:active {
        cursor: default;
        color: rgba(200, 200, 200, 0.9) !important;
        border: 1px solid transparent;
        background: transparent;
        box-shadow: none;
    }

    .dataTables_wrapper .dataTables_paginate .paginate_button {
        box-sizing: border-box;
        display: inline-block;
        min-width: 1.5em;
        padding: 0.5em 1em;
        margin-left: 2px;
        text-align: center;
        text-decoration: none !important;
        cursor: pointer;
        cursor: hand;
        color: rgba(200, 200, 200, 0.9) !important;
        border: 0;
        border-radius: 0.375rem;
    }

    .dataTables_wrapper .dataTables_paginate .paginate_button:hover {
        color: rgba(200, 200, 200, 1) !important;
        background-color: rgba(0, 152, 219, 0.1) !important;
        background-image: unset !important;
        border: 0;
    }

    /*.loader {
        border: 4px solid #f3f3f3;
        border-top: 4px solid #05fff3;
        border-radius: 50%;
        width: 20px;
        height: 20px;
        z-index: 500;
        animation: spin 1s linear infinite;
    }

    @keyframes spin {
        0% { transform: rotate(0deg);}
        100% { transform: rotate(360deg); }
    }*/

    .loader {
        display: inline-block;
        position: relative;
        width: 25px;
        height: 25px;
        z-index: 500;
    }
    .loader div {
        box-sizing: border-box;
        display: block;
        position: absolute;
        width: 20px;
        height: 20px;
        margin: 3px;
        border: 3px solid #05fff3;
        border-radius: 50%;
        animation: loader 1.2s cubic-bezier(0.5, 0, 0.5, 1) infinite;
        border-color: #05fff3 transparent transparent transparent;
    }
    .loader div:nth-child(1) {
        animation-delay: -0.45s;
    }
    .loader div:nth-child(2) {
        animation-delay: -0.3s;
    }
    .loader div:nth-child(3) {
        animation-delay: -0.15s;
    }
    @keyframes loader {
        0% {
            transform: rotate(0deg);
        }
        100% {
            transform: rotate(360deg);
        }
    }
</style>

<template>
    <AppLayoutBasic title="AdminDashboard">
        <loader-component></loader-component>
        <div v-if="this.screen_width >= 768" style="height: calc(100vh - 4.75rem)" class="bg-darkblue-background z-0 cursor-default">
            <div class="flex flex-col h-full w-full px-6 py-4 gap-y-4 gap-x-6 overflow-y-scroll">
                <div class="flex justify-between items-center">
                    <p class="text-white-snow font-light text-left text-2xl">{{ this.$t("general.AdminDashboard") }} </p>
                    <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('waterGlobalViewDemo')" v-if="this.isWater()" v-show="this.user.admin == 0">
                        <DK_Button color="blue" :fixedSize="true">
                            Demo
                        </DK_Button>
                    </Link>
                    <DK_Button v-else v-on:click="this.openModal()"  color="blue" :fixedSize="true" v-show="this.user.admin == 0">
                        Demo
                    </DK_Button>
                </div>
                <div class="w-full flex flex-col gap-4">
                    <div class="px-6 pt-3 pb-2 baltoro-container flex flex-col h-fit w-full overflow-y-hidden ">
                        <div class="w-full flex flex-row justify-between items-center">
                            <p class="text-white-snow font-light text-left text-2xl">{{ this.$t("general.Group")+'s' }} </p>
                            <DK_Input id="searchInputMultitenant" type="text" textPosition="left" value="" :border="true" width="15rem" :placeholder="this.$t('general.Search') + ' ' + this.$t('general.Groups').toLowerCase()+'...'"></DK_Input>
                        </div>
                        <table id="multitenantTable" class="row-border w-full">
                            <thead class="bg-transparent text-gray-light">
                                <tr>
                                    <th>
                                        <div class="w-full flex justify-around">
                                            <a class="w-full text-center">{{ this.$t("general.GroupId") }}</a>
                                            <a class="w-full text-center">{{ this.$t("general.Name") }}</a>
                                            <a class="w-full text-center">{{ this.$t("general.Gateways") }}</a>
                                        </div>
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="text-center">
                                <tr class="bg-transparent items-center" v-for="(data, index) in this.multitenant" :key="index" style="cursor: pointer">
                                    <td>
                                        <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('routing', { idgroup: this.multitenant[index].idgroup, idplatform: this.multitenant[index].idsolution })">
                                            <div class="w-full flex justify-around">
                                                <a class="w-full text-center">{{ this.multitenant[index].idgroup }}</a>
                                                <a class="w-full text-center">{{ this.multitenant[index].name }}</a>
                                                <a class="w-full text-center">{{ this.multitenant[index].device_number }}</a>
                                            </div>
                                        </Link>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                    <div class="px-6 pt-3 pb-2 baltoro-container flex flex-col h-fit w-full overflow-y-hidden ">
                        <div class="w-full flex flex-row justify-between items-center">
                            <p class="text-white-snow font-light text-left text-2xl">{{ this.$t("general.Devices") }} </p>
                            <div class="flex flex-row justify-end gap-4 items-center">
                                <div class="h-6 w-6 text-white-snow" v-if="this.preload">
                                    <div class="loader"><div></div><div></div><div></div><div></div></div>
                                </div>
                                <DK_Input id="searchInputDevices" type="text" textPosition="left" value="" :border="true" width="15rem" :placeholder="this.$t('general.Search') + ' ' + this.$t('general.Devices').toLowerCase()+'...'"></DK_Input>
                            </div>
                        </div>
                        <table id="DevicesTable" class="row-border w-full">
                            <thead class="bg-transparent text-gray-light">
                                <tr>
                                    <th>
                                        {{ this.$t('general.GatewayID') }}
                                    </th>
                                    <th>
                                        {{ this.$t('general.Name') }}
                                    </th>
                                    <th>
                                        {{ this.$t("general.Version") }}
                                    </th>
                                    <th>
                                        {{ this.$t('general.Group') }}
                                    </th>
                                    <th class="w-[7rem]">
                                        {{ this.$t("general.Readings") }}
                                    </th>
                                    <th class="w-[7rem]">
                                        {{ this.$t("general.Profile") }}
                                    </th>
                                    <th class="w-[7rem]">
                                        {{ this.$t("general.Dashboard") }}
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="text-center" v-bind:class="{'opacity-50' : this.preload}">
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div v-else style="height: calc(100vh - 4.75rem)" class="bg-darkblue-background z-0 cursor-default ">
            <div class="flex flex-col h-full w-full px-6 py-4 gap-y-4 gap-x-6 overflow-y-scroll">
                <div class="flex justify-between items-center">
                    <p class="text-white-snow font-light text-left text-xl whitespace-nowrap">{{ this.$t("general.AdminDashboard") }} </p>
                    <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('waterGlobalViewDemo')" v-if="this.isWater()">
                        <!--<DK_Button color="blue" :fixedSize="true">
                            Demo
                        </DK_Button>-->
                        <button type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                            <i class="fa-solid fa-laptop-code " style="font-size:14px; color:#FFFAFA; "></i>
                        </button>
                    </Link>
                    <!--<DK_Button v-else v-on:click="this.openModal()"  color="blue" :fixedSize="true">
                        Demo
                    </DK_Button>-->
                    <button v-else v-on:click="this.openModal()" type="button" class="text-white-snow button-blue font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center">
                        <i class="fa-solid fa-laptop-code " style="font-size:14px; color:#FFFAFA; "></i>
                    </button>
                </div>
                <div class="w-full flex flex-col gap-6">
                    <div class="px-6 pt-3 pb-2 baltoro-container flex flex-col h-fit w-full overflow-y-hidden ">
                        <div class="w-full flex flex-row justify-between items-center">
                            <p class="text-white-snow font-light text-left text-xl">{{ this.$t("general.Group")+'s' }}</p>
                            <DK_Input id="searchInputMultitenant" type="text" textPosition="left" value="" :border="true" width="10rem" :placeholder="this.$t('general.Search') + ' ' + this.$t('general.Groups').toLowerCase()+'...'"></DK_Input>
                        </div>
                        <table id="multitenantTable" class="row-border w-full">
                            <thead class="bg-transparent text-gray-light">
                                <tr>
                                    <th>
                                        <div class="w-full flex justify-around">
                                            <a class="w-full text-center">{{ this.$t("general.GroupId") }}</a>
                                            <a class="w-full text-center">{{ this.$t("general.Name") }}</a>
                                            <a class="w-full text-center">{{ this.$t("general.Gateways") }}</a>
                                        </div>
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="text-center">
                                <tr class="bg-transparent items-center" v-for="(data, index) in this.multitenant" :key="index" style="cursor: pointer">
                                    <td>
                                        <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('routing', { idgroup: this.multitenant[index].idgroup, idplatform: this.multitenant[index].idsolution })">
                                            <div class="w-full flex justify-around">
                                                <a class="w-full text-center">{{ this.multitenant[index].idgroup }}</a>
                                                <a class="w-full text-center">{{ this.multitenant[index].name }}</a>
                                                <a class="w-full text-center">{{ this.multitenant[index].device_number }}</a>
                                            </div>
                                        </Link>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                    <div class="px-6 pt-3 pb-2 baltoro-container flex flex-col h-fit w-full overflow-y-hidden  relative">
                        <div class="w-full flex flex-row justify-between items-center">
                            <p class="text-white-snow font-light text-left text-xl">{{ this.$t("general.Devices") }} </p>
                            <div class="flex flex-row justify-end gap-4 items-center">
                                <div class="h-6 w-6 text-white-snow" v-if="this.preload">
                                    <div class="loader"><div></div><div></div><div></div><div></div></div>
                                </div>
                                <DK_Input id="searchInputDevices" type="text" textPosition="left" value="" :border="true" width="10rem" :placeholder="this.$t('general.Search') + ' ' + this.$t('general.Devices').toLowerCase()+'...'"></DK_Input>
                            </div>
                        </div>
                        <table id="DevicesTable" class="row-border w-full">
                            <thead class="bg-transparent text-gray-light">
                                <tr>
                                    <th>
                                        {{ this.$t('general.GatewayID') }}
                                    </th>
                                    <th>
                                        {{ this.$t('general.Name') }}
                                    </th>
                                    <th>
                                        {{ this.$t("general.Version") }}
                                    </th>
                                    <th>
                                        {{ this.$t('general.Group') }}
                                    </th>
                                    <th>
                                        {{ this.$t("general.Readings") }}
                                    </th>
                                    <th>
                                        {{ this.$t("general.Profile") }}
                                    </th>
                                    <th>
                                        {{ this.$t("general.Dashboard") }}
                                    </th>
                                </tr>
                            </thead>
                            <tbody class="text-center" v-bind:class="{'opacity-50' : this.preload}">
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>

        <JetModal :show="this.demo_modal" :closeable="false">

            <div class="overflow-y-auto max-h-[85vh] pt-3 cursor-default max-w-[40rem] p-4" v-bind:class="{'w-fit' : this.screen_width >= 768, 'w-[90vw]' : this.screen_width < 768}">

                <p class="text-md text-center text-cyan-text font-light whitespace-nowrap p-2">
                    {{ this.$t("general.democity") }}
                </p>

                <table id="device_type_Table" class="row-border">
                    <thead class="bg-transparent text-gray-light my-2">
                        <tr>
                            <th>
                                <div class="flex justify-around">
                                    <a class="text-center whitespace-nowrap">{{ this.$t("general.Select device type") }}</a>
                                </div>
                            </th>
                        </tr>
                    </thead>
                    <tbody class="text-center">
                        <!--<tr class="bg-transparent items-center" style="cursor: pointer">
                            <td>
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityGlobalViewDemo', { device_type:  0 })">
                                    <div class="w-full flex justify-around">
                                        <a class="text-center">{{ this.$t("general.Vacon") }}</a>
                                    </div>
                                </Link>
                            </td>
                        </tr>-->
                        <tr class="bg-transparent items-center" style="cursor: pointer">
                            <td>
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityGlobalViewDemo', { device_type:  1 })">
                                    <div class="w-full flex justify-around">
                                        <a class="text-center">{{ this.$t("general.Meteo") }}</a>
                                    </div>
                                </Link>
                            </td>
                        </tr>
                        <tr class="bg-transparent items-center" style="cursor: pointer">
                            <td>
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityGlobalViewDemo', { device_type:  2 })">
                                    <div class="w-full flex justify-around">
                                        <a class="text-center">{{ this.$t("general.Sonometer") }}</a>
                                    </div>
                                </Link>
                            </td>
                        </tr>
                        <tr class="bg-transparent items-center" style="cursor: pointer">
                            <td>
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityGlobalViewDemo', { device_type:  3 })">
                                    <div class="w-full flex justify-around">
                                        <a class="text-center">{{ this.$t("general.Park") }}</a>
                                    </div>
                                </Link>
                            </td>
                        </tr>
                        <tr class="bg-transparent items-center" style="cursor: pointer">
                            <td>
                                <Link onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" :href="route('cityGlobalViewDemo', { device_type:  4 })">
                                    <div class="w-full flex justify-around">
                                        <a class="text-center">{{ this.$t("general.Sensor") }}</a>
                                    </div>
                                </Link>
                            </td>
                        </tr>
                    </tbody>
                </table>
                <div class="pt-4 flex flex-row items-center justify-center">
                    <DK_Button v-on:click="this.closeModal()"  color="blue" :fixedSize="true">Cancel</DK_Button>
                </div>
            </div>

        </JetModal>

    </AppLayoutBasic>
</template>

<script>
export default {
    data() {
        return {
            screen_width: 0,
            demo_modal: false,
            searchTerm: '',
            timer: null,
            preload: false,
        };
    },
    props: ["multitenant", "idportal", "user"],

    beforeCreate: function () {
        this.$i18n.locale = this.user.language;
    },

    beforeMount() {
        this.screen_width = window.screen.width;
        //this.screen_width = 767;
    },

    mounted() {

        window.emitter.emit('changeLoaderStatus', false, 'orbit')

        this.table_multitenant = $("#multitenantTable").DataTable({
            language: {
                url: "/assets/i18n/" + this.user.language + ".json",
            },
            searching: true,
            ordering: true,
            dom: '<"row"<"col-sm-6"><"col-sm-6"f>>t<"row"<"col-sm-6"><"col-sm-6"p>><"clear">',
            "columnDefs": [
                { "orderable": false, "targets":  false ? [0, 1] : [], }
            ],
            paging: true,
            pageLength: this.screen_width > 1280 ? 8 : (this.screen_width >= 768 ? 6 : 8),
        });

        this.table_devices = $("#DevicesTable").DataTable({
            language: {
                url: "/assets/i18n/" + this.user.language + ".json",
            },
            searching: true,
            ordering: true,
            dom: '<"row"<"col-sm-6"><"col-sm-6"f>>t<"row"<"col-sm-6"><"col-sm-6"p>><"clear">',
            paging: true,
            pageLength: this.screen_width > 1280 ? 8 : (this.screen_width >= 768 ? 6 : 8),
        });

        const self = this;  // Almacenamos una referencia a "this" para su uso dentro del manejador

        this.table_devices.on('draw.dt', () => {

            var data = this.table_devices.rows({ page: 'current' }).data();
            var parser = new DOMParser();

            data.each(function (value, index) {

                var idDevice = parser.parseFromString(value[0], 'text/xml').querySelector('td').textContent;
                var type = parser.parseFromString(value[2], 'text/xml').querySelector('td').textContent;
                var gatewayInfo = {
                    modbusDeviceType: parser.parseFromString(value[7], 'text/xml').querySelector('td').textContent,
                    idSolution: parser.parseFromString(value[8], 'text/xml').querySelector('td').textContent,
                }

                self.createClickableButton('readings', idDevice)

                if(!self.isPark(type))
                    self.createClickableButton('profile', idDevice)

                self.createClickableButton(self.screenDisplay(gatewayInfo, true), idDevice)
            });
        });

        // Vincular el campo de búsqueda personalizado con DataTables
        $('#searchInputMultitenant').on('keyup', function() {
            const searchTerm = this.value;
            self.table_multitenant.search(searchTerm);
            self.table_multitenant.draw();  // Actualiza la tabla después de la búsqueda
        });

        $('#searchInputDevices').on('keyup', function() {
            const searchTermDevices = this.value;

            self.preload = true;

            // Cancelar el temporizador anterior si existe
            if (self.timer) {
                clearTimeout(self.timer);
            }

            // Establecer un nuevo temporizador
            self.timer = setTimeout(() => {

                if (typeof searchTermDevices !== 'undefined' && searchTermDevices !== '') {
                    axiosApiCalls.methodGet('/gateways/multitenant/' + self.user.id + '/' + searchTermDevices + '/' + self.idportal, self.user.token, false)
                    .then((response) => {

                        self.table_devices.clear();

                        if (response.length != 0) {

                            response.forEach((gateway, index) => {

                                self.table_devices.row.add([
                                    '<td>' + gateway.idDevice + '</td>',
                                    '<td>' + gateway.name + '</td>',
                                    '<td>' + gateway.type + '</td>',
                                    '<td>' + gateway.groupName + '</td>',
                                    '<td>' + // READINGS
                                        '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                                            '<button id="id_readings_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                                '<i class="fa-solid fa-chart-column" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                                            '</button>' +
                                        '</div>' +
                                    '</td>',
                                    '<td>' + // PROFILE
                                        ( !self.isPark(gateway.type) ?
                                        '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                                            '<button id="id_profile_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800">' +
                                                '<i class="fa-solid fa-gears" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                                            '</button>' +
                                        '</div>' : '' ) +
                                    '</td>',
                                    '<td>' + self.screenDisplay(gateway) + '</td>',
                                    '<td class="invisible">' + gateway.modbusDeviceType + '</td>',
                                    '<td class="invisible">' + gateway.idSolution + '</td>',
                                ]);
                            })
                        }

                        self.table_devices.draw(false)

                        if(searchTermDevices == this.value)
                            self.preload = false;
                    })
                } else {
                    clearTimeout(self.timer);
                    self.table_devices.clear().draw(false);
                    self.preload = false;
                }

            }, 450);
        });

        window.emitter.emit("changeLoaderStatus", false);
    },

    methods: {
        isWater(){
            return window.location.origin.indexOf('localhost:8000') !== -1 || window.location.origin.indexOf('water.baltoro.app') !== -1;
        },

        isPark(type) {
            return type.toLowerCase().includes('park');
        },

        screenDisplay(gateway, selector){

            if(gateway.modbusDeviceType == 6 || gateway.modbusDeviceType == 7) {
                if(selector == true){
                    return 'vacon';
                }else{
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_vacon_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-box" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                    }
            } else if(gateway.modbusDeviceType == 23) {
                if(selector == true){
                    return 'rtdashboard';
                }else{
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_rtdashboard_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-bolt" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                }
            } else if(gateway.modbusDeviceType == 34) {
                if(selector == true){
                    return 'optidrive';
                }else{
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_optidrive_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-bolt" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                }
            } else if(gateway.idSolution == 8) {
                if(selector == true){
                    return 'meteo';
                } else {
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_meteo_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-cloud-sun" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                }
            } else if(gateway.idSolution == 9) {
                if(selector == true){
                    return 'valve';
                } else {
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_valve_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-gauge-high" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                }
            } else if(gateway.idSolution == 10) {
                if(selector == true){
                    return 'wilo';
                } else {
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_wilo_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-gauge-high" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                }
            } else if(gateway.idSolution == 11) {
                if(selector == true){
                    return 'ullastres';
                } else {
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_ullastres_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-droplet" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                }
            } else if(gateway.idSolution == 12) {
                if(selector == true){
                    return 'rtgRegisters';
                } else {
                    return '<div class="flex items-center justify-center px-1 py-0.5 w-full">' +
                            '<button id="id_rtgRegisters_' + gateway.idDevice + '" type="button" class="miClase w-[1.625rem] h-[1.625rem] text-white-snow bg-blue-700 hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm p-1.5 text-center inline-flex items-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 grid place-items-center">' +
                                '<i class="fa-solid fa-gauge-high" style="font-size:0.75rem; color:#FFFAFA;"></i>' +
                            '</button>' +
                        '</div>';
                }
            }

            return '';
        },

        openModal(){
            this.demo_modal = true

            setTimeout(() => {
                this.table_multitenant_modal = $("#device_type_Table").DataTable({
                    language: {
                        url: "/assets/i18n/" + this.user.language + ".json",
                    },
                    searching: false,
                    ordering: false,
                    paging: false,
                    dom: '<"row"<"col-sm-6"><"col-sm-6"f>>t<"row"<"col-sm-6"><"col-sm-6"p>><"clear">',
                });
            }, 0);
        },

        closeModal(){
            this.demo_modal = false
        },

        createClickableButton(keyScreen, idDevice){

            if ( keyScreen != '' && document.getElementById("id_" + keyScreen + '_' + idDevice) != null) {

                document
                .getElementById("id_" + keyScreen + '_' + idDevice)
                .addEventListener("click", () => {
                    window.emitter.emit('changeLoaderStatus', true, 'orbit')
                    this.$inertia.visit(route('rerouting', { idDevice: idDevice, keyScreen: keyScreen }));
                })
            }
        },
    },
};
</script>
